% % =======================================================================
% % This code evaluates the log likelihood ratio
% % See: 
% % Chan, J. C. C. and Kroese, D. K. (2012). "Improved Cross-Entropy Method
% % for Estimation", Statistics and Computing, 22(5), 1031-1040.
% %
% % Please report any errors to joshuacc.chan@gmail.com
% % =======================================================================

function lw = LR(vmpara,X,nu,sig_eta)
Zmu = vmpara(1);
Zvar = vmpara(2); 
alpt = vmpara(3);
lamt = vmpara(4);
etamu = vmpara(5);

Z = X(:,1);
Q = X(:,2);
eta = X(:,3:end);
n = size(eta,2);

c = nu/2*log(nu/2) - gammaln(nu/2) - alpt*log(lamt) + gammaln(alpt);
w = log(Zvar)/2 - 1/2*(Z.^2 - (Z-Zmu).^2/Zvar);
w = w + c + (nu/2-alpt)*log(Q) - (nu/2-lamt)*Q;
w = w - 1/(2*sig_eta) * (2*sum(eta,2)*etamu - n*etamu^2);
maxw = max(w);
lw = log(mean(exp(w-maxw))) + maxw;
end