% % =======================================================================
% % This function returns N draws from a left truncated normal distribution
% % with mean mu, cov sigma2 and truncation point a
% % See: 
% % Chan, J. C. C. and Kroese, D. K. (2012). "Improved Cross-Entropy Method
% % for Estimation", Statistics and Computing, 22(5), 1031-1040.
% %
% % Please report any errors to joshuacc.chan@gmail.com
% % =======================================================================

function t = ltnormrnd( mu, sigma2, a, N)

K = length( mu );

if K == 1
    mu = ones( N, 1 ) * mu;
    sigma2 = ones( N, 1 ) * sigma2;
end

sigma = sqrt( sigma2 );
u = rand(N,1);
p1 = normcdf( ( a - mu ) ./ sigma );
C = norminv( p1 + ( 1 - p1 ) .* u );
t = mu + sigma .* C;
end